@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -320,12 +320,14 @@ action_proc_dot_add_link( Expr *expr, Symbol *child )
 }
 
 static char *
-action_proc_dot_tag( PElement *b, char *tag, int n )
+action_proc_dot_tag( Reduce *rc, PElement *b, char *tag, int n )
 {
 	if( PEISTAG( b ) ) 
 		return( PEGETTAG( b ) );
-	else if( heap_get_string( b, tag, n ) )
+	else if( reduce_is_string( rc, b ) ) { 
+		(void) reduce_get_string( rc, b, tag, n );
 		return( tag );
+	}
 
 	return( NULL );
 }
@@ -342,7 +344,7 @@ action_proc_dot( Reduce *rc, Compile *compile,
 	if( PEISCLASS( a ) ) {
 		PElement c;
 
-		if( (p = action_proc_dot_tag( b, tag, 256 )) ) {
+		if( (p = action_proc_dot_tag( rc, b, tag, 256 )) ) {
 			if( !class_get_member( a, p, NULL, &c ) )
 				action_nomerror( rc, compile, a, b );
 
@@ -372,7 +374,7 @@ action_proc_dot( Reduce *rc, Compile *compile,
 
 		g_assert( sym->expr );
 
-		if( !(p = action_proc_dot_tag( b, tag, 256 )) ) 
+		if( !(p = action_proc_dot_tag( rc, b, tag, 256 )) ) 
 			action_boperror( rc, compile, 
 				_( "Bad right hand side of '.'." ),
 				op, name, a, b );
@@ -402,7 +404,7 @@ action_proc_dot( Reduce *rc, Compile *compile,
 		GValue value = { 0 };
 		GParamSpec *pspec;
 
-		if( !(p = action_proc_dot_tag( b, tag, 256 )) )
+		if( !(p = action_proc_dot_tag( rc, b, tag, 256 )) )
 			action_boperror( rc, compile, 
 				_( "Bad right hand side of '.'." ),
 				op, name, a, b );
