@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -72,24 +72,73 @@ columnview_clone_cb( GtkWidget *wid, GtkWidget *host, Columnview *cview )
 {
 	Column *col = COLUMN( VOBJECT( cview )->iobject );
 	Workspace *ws = col->ws;
-	char *newname = workspace_column_name_new( ws, NULL );
-        Column *newcol = workspace_column_get( ws, newname );
 
-	IM_FREE( newname );
+	char new_name[MAX_STRSIZE];
+        Column *newcol;
+
+	workspace_column_name_new( ws, new_name );
+        newcol = workspace_column_get( ws, new_name );
         iobject_set( IOBJECT( newcol ), NULL, IOBJECT( col )->caption );
-        newcol->x = col->x + 30;
-        newcol->y = col->y + 30;
+        newcol->x = col->x + 100;
+        newcol->y = col->y;
 
 	workspace_deselect_all( ws );
         column_select_symbols( col );
 	workspace_column_select( ws, newcol );
-        if( !workspace_clone_selected( ws ) )
+        if( !workspace_selected_duplicate( ws ) )
 		iwindow_alert( GTK_WIDGET( cview ), GTK_MESSAGE_ERROR );
 	workspace_deselect_all( ws );
 
         symbol_recalculate_all();
 }
 
+static void
+columnview_merge_sub( iWindow *iwnd, 
+	void *client, iWindowNotifyFn nfn, void *sys )
+{
+	Filesel *filesel = FILESEL( iwnd );
+	Column *col = COLUMN( client );
+	Workspace *ws = col->ws;
+	Workspacegroup *wsg = workspace_get_workspacegroup( ws );
+
+	char *filename;
+	iWindowResult result;
+
+	result = IWINDOW_YES;
+	progress_begin();
+
+	if( (filename = filesel_get_filename( filesel )) ) {
+		if( !workspacegroup_merge_rows( wsg, filename ) ) 
+			result = IWINDOW_ERROR;
+
+		g_free( filename );
+	}
+
+	symbol_recalculate_all();
+	progress_end();
+
+	nfn( sys, result );
+}
+
+static void
+columnview_merge_cb( GtkWidget *wid, GtkWidget *host, Columnview *cview )
+{
+	Column *col = COLUMN( VOBJECT( cview )->iobject );
+	iWindow *iwnd = IWINDOW( view_get_toplevel( VIEW( cview ) ) );
+	GtkWidget *filesel = filesel_new();
+
+	iwindow_set_title( IWINDOW( filesel ), 
+		_( "Merge Into Column \"%s\"" ), IOBJECT( col )->name );
+	filesel_set_flags( FILESEL( filesel ), FALSE, FALSE );
+	filesel_set_filetype( FILESEL( filesel ), filesel_type_workspace, 0 ); 
+	iwindow_set_parent( IWINDOW( filesel ), GTK_WIDGET( iwnd ) );
+	idialog_set_iobject( IDIALOG( filesel ), IOBJECT( col ) );
+	filesel_set_done( FILESEL( filesel ), columnview_merge_sub, col );
+	iwindow_build( IWINDOW( filesel ) );
+
+	gtk_widget_show( GTK_WIDGET( filesel ) );
+}
+
 /* Callback from save browser.
  */
 static void
@@ -205,7 +254,7 @@ columnview_to_menu_done_cb( iWindow *iwnd, void *client,
 	workspace_deselect_all( ws );
 
 	if( !tool_new_dia( toolkit_by_name( ws->kitg, toolkit_text ), 
-			-1, name_text, file_text ) ) {
+		-1, name_text, file_text ) ) {
 		unlinkf( "%s", file_text );
 		nfn( sys, IWINDOW_ERROR );
 		return;
@@ -353,45 +402,40 @@ columnview_left_press( Columnview *cview, GdkEvent *ev )
         }
 }
 
-typedef struct {
-	Column *col;		/* Column we are snapping */
-	Column *best;		/* Closest we've found so far */
-} ColumnviewSnap;
-
-static void *
-columnview_snap_column( Column *col, ColumnviewSnap *snap )
-{
-	if( col != snap->col )
-		if( !snap->best ||
-			IM_ABS( col->x - snap->col->x ) < 
-				IM_ABS( snap->best->x - snap->col->x ) ) 
-			snap->best = col;
-
-	return( NULL );
-}
-
 static void
-columnview_snap( Column *col )
+columnview_add_shadow( Columnview *old_cview )
 {
-	const int SNAP_THRESHOLD = 20;
-	Workspace *ws = col->ws;
-	ColumnviewSnap snap;
-	
-	/* Find the column closest to this one.
-	 */
-	snap.col = col;
-	snap.best = NULL;
-	(void) workspace_map_column( ws, 
-		(column_map_fn) columnview_snap_column, &snap );
+	Column *col = COLUMN( VOBJECT( old_cview )->iobject );
+	Workspaceview *wview = old_cview->wview;
 
-	if( snap.best && IM_ABS( snap.best->x - col->x ) < SNAP_THRESHOLD ) 
-		col->x = snap.best->x;
+	if( !old_cview->shadow ) { 
+		Columnview *new_cview;
+
+		new_cview = COLUMNVIEW( columnview_new() ); 
+		new_cview->wview = wview; 
+		VIEW( new_cview )->parent = VIEW( wview ); 
+		VOBJECT( new_cview )->iobject = IOBJECT( col ); 
+
+		gtk_fixed_put( GTK_FIXED( wview->fixed ),
+			GTK_WIDGET( new_cview ), col->x, col->y );
+
+		gtk_widget_show( GTK_WIDGET( new_cview ) ); 
+
+		old_cview->shadow = new_cview;
+		new_cview->master = old_cview;
+
+		/* The shadow will be on top of the real column and hide it. 
+		 * Put the real column to the front.
+		 */
+		model_front( MODEL( col ) ); 
+	}
 }
 
 static void
 columnview_left_motion( Columnview *cview, GdkEvent *ev )
 {
 	Column *col = COLUMN( VOBJECT( cview )->iobject );
+	Workspace *ws = col->ws;
 	Workspaceview *wview = cview->wview;
 
 	int u, v;
@@ -431,6 +475,9 @@ columnview_left_motion( Columnview *cview, GdkEvent *ev )
                 if( abs( xoff ) > 5 || abs( yoff ) > 5 ) {
                         cview->state = COL_DRAG;
 			workspaceview_set_cursor( wview, IWINDOW_SHAPE_MOVE );
+			gtk_grab_add( cview->title ); 
+
+			columnview_add_shadow( cview );
                 }
 
                 break;
@@ -439,10 +486,6 @@ columnview_left_motion( Columnview *cview, GdkEvent *ev )
 		col->x = xnew;
 		col->y = ynew;
 
-		/* Snap to other column x positions.
-		 */
-		columnview_snap( col );
-
 		iobject_changed( IOBJECT( col ) );
 
 #ifdef DEBUG
@@ -465,6 +508,10 @@ columnview_left_motion( Columnview *cview, GdkEvent *ev )
 
 		workspaceview_scroll_background( wview, u, v );
 
+		/* Move other columns about.
+		 */
+		model_layout( MODEL( ws ) ); 
+
                 break;
 
         default:
@@ -489,15 +536,20 @@ columnview_left_release( Columnview *cview, GdkEvent *ev )
         case COL_SELECT:
                 cview->state = COL_WAIT;
                 workspace_column_select( ws, col );
-                view_child_front( VIEW( cview ) );
 
                 break;
 
         case COL_DRAG:
                 cview->state = COL_WAIT;
 		workspaceview_scroll_background( wview, 0, 0 );
-		filemodel_set_modified( FILEMODEL( ws ), TRUE );
 		workspaceview_set_cursor( wview, IWINDOW_SHAPE_NONE );
+		gtk_grab_remove( cview->title ); 
+		DESTROY_GTK( cview->shadow ); 
+
+		/* Move columns to their final position.
+		 */
+		model_layout( MODEL( ws ) ); 
+		workspace_set_modified( ws, TRUE );
 
                 break;
 
@@ -513,12 +565,18 @@ columnview_left_release( Columnview *cview, GdkEvent *ev )
 /* Event in columnview title bar.
  */
 static gboolean
-columnview_event_cb( GtkWidget *widget, GdkEvent *ev, Columnview *cview )
+columnview_title_event_cb( GtkWidget *widget, GdkEvent *ev, Columnview *cview )
 {
 	gboolean handled = FALSE;
 
 #ifdef DEBUG
-	printf( "columnview_event_cb %d\n", ev->type );
+{
+	Column *col = COLUMN( VOBJECT( cview )->iobject );
+
+	printf( "columnview_title_event_cb: %s %d\n", 
+		IOBJECT( col )->name, 
+		ev->type );
+}
 #endif /*DEBUG*/
 
         switch( ev->type ) {
@@ -564,6 +622,55 @@ columnview_event_cb( GtkWidget *widget, GdkEvent *ev, Columnview *cview )
         return( handled );
 }
 
+static void 
+columnview_destroy( GtkObject *object )
+{
+	Columnview *cview;
+	Column *col;
+
+	g_return_if_fail( object != NULL );
+	g_return_if_fail( IS_COLUMNVIEW( object ) );
+
+	cview = COLUMNVIEW( object );
+	col = COLUMN( VOBJECT( cview )->iobject );
+
+#ifdef DEBUG
+	printf( "columnview_destroy:\n" );
+#endif /*DEBUG*/
+
+	DESTROY_GTK( cview->shadow );
+
+	/* The column has gone .. relayout.
+	 */
+	if( col &&
+		col->ws ) {
+		workspace_set_needs_layout( col->ws, TRUE ); 
+		mainw_layout();
+	}
+
+	GTK_OBJECT_CLASS( parent_class )->destroy( object );
+}
+
+static void
+columnview_size_allocate( GtkWidget *widget, GtkAllocation *allocation )
+{
+	Columnview *cview = COLUMNVIEW( widget ); 
+
+	if( cview->old_width != allocation->width ||
+		cview->old_height != allocation->height ) { 
+		Column *col = COLUMN( VOBJECT( cview )->iobject );
+		Workspace *ws = col->ws;
+
+		cview->old_width = allocation->width;
+		cview->old_height = allocation->height;
+
+		workspace_set_needs_layout( ws, TRUE ); 
+		mainw_layout();
+	}
+
+	GTK_WIDGET_CLASS( parent_class )->size_allocate( widget, allocation );
+}
+
 /* Arrow button on title bar.
  */
 static void
@@ -581,7 +688,8 @@ columnview_destroy_cb( GtkWidget *wid, GtkWidget *host, Columnview *cview )
 {
 	Column *col = COLUMN( VOBJECT( cview )->iobject );
 
-	model_check_destroy( view_get_toplevel( VIEW( cview ) ), MODEL( col ) );
+	model_check_destroy( view_get_toplevel( VIEW( cview ) ), 
+		MODEL( col ), NULL );
 }
 
 /* Delete this column with a click on the 'x' button.
@@ -591,7 +699,8 @@ columnview_destroy2_cb( GtkWidget *wid, Columnview *cview )
 {
 	Column *col = COLUMN( VOBJECT( cview )->iobject );
 
-	model_check_destroy( view_get_toplevel( VIEW( cview ) ), MODEL( col ) );
+	model_check_destroy( view_get_toplevel( VIEW( cview ) ), 
+		MODEL( col ), NULL );
 }
 
 /* Callback for enter in caption edit box.
@@ -609,7 +718,7 @@ columnview_caption_enter_cb( GtkWidget *wid, Columnview *cview )
 	if( strcmp( text, "" ) != 0 ) 
 		iobject_set( IOBJECT( col ), NULL, text );
 
-	filemodel_set_modified( FILEMODEL( ws ), TRUE );
+	workspace_set_modified( ws, TRUE );
 
 	/* The ws view needs to update the jumpto menus.
 	 */
@@ -705,12 +814,31 @@ static void
 columnview_refresh( vObject *vobject )
 {
 	Columnview *cview = COLUMNVIEW( vobject );
+	Columnview *shadow = cview->shadow;
 	Column *col = COLUMN( VOBJECT( cview )->iobject );
 	gboolean editable = col->ws->mode != WORKSPACE_MODE_NOEDIT;
 
-	/* Update position.
+#ifdef DEBUG
+	printf( "columnview_refresh: %s\n", IOBJECT( col )->name );
+#endif /*DEBUG*/
+
+	/* If this column has a shadow, workspaceview will have put a layout
+	 * position into it. See workspaceview_layout_set_pos(). 
 	 */
-	if( col->x != cview->lx || col->y != cview->ly ) {
+	if( shadow )  
+		view_child_position( VIEW( shadow ) ); 
+
+	if( shadow ) {
+		gtk_widget_set_size_request( GTK_WIDGET( shadow->frame ), 
+			GTK_WIDGET( cview->frame )->allocation.width, 
+			GTK_WIDGET( cview->frame )->allocation.height );
+		gtk_frame_set_shadow_type( GTK_FRAME( shadow->frame ),
+			GTK_SHADOW_IN );
+	}
+
+
+	if( col->x != cview->lx || 
+		col->y != cview->ly ) {
 #ifdef DEBUG
 		printf( "columnview_refresh: move column %s to %d x %d\n",
 			IOBJECT( col )->name, col->x, col->y );
@@ -768,6 +896,7 @@ columnview_refresh( vObject *vobject )
                         GTK_ARROW_RIGHT, GTK_SHADOW_OUT );
                 set_tooltip( cview->updownb, _( "Open the column" ) );
 	}
+	model_display( MODEL( col->scol ), col->open );
 
 	/* Closed columns are hidden in NOEDIT mode.
 	 */
@@ -785,8 +914,7 @@ columnview_refresh( vObject *vobject )
 			set_gentry( cview->capedit, "%s", 
 				IOBJECT( col )->caption );
 			gtk_editable_select_region( 
-				GTK_EDITABLE( cview->capedit ),
-				0, strlen( IOBJECT( col )->caption ) );
+				GTK_EDITABLE( cview->capedit ), 0, -1 );
 		}
                 gtk_widget_grab_focus( cview->capedit );
         }
@@ -797,7 +925,10 @@ columnview_refresh( vObject *vobject )
 
         /* Set bottom entry.
          */
-        if( col->selected && col->open && editable ) {
+        if( col->selected && 
+		col->open && 
+		editable &&
+		!cview->master ) {
                 columnview_add_text( cview );
                 gtk_widget_show( cview->textfr );
         }
@@ -806,7 +937,9 @@ columnview_refresh( vObject *vobject )
 
 	/* Set select state.
 	 */
-        if( col->selected && !cview->selected ) {
+        if( cview->master ) 
+                gtk_widget_set_name( cview->title, "shadow_widget" );
+	else if( col->selected && !cview->selected ) {
                 gtk_widget_set_name( cview->title, "selected_widget" );
 		cview->selected = TRUE;
 		if( cview->textfr )
@@ -872,6 +1005,8 @@ columnview_scrollto( View *view, ModelScrollPosition position )
 static void
 columnview_class_init( ColumnviewClass *class )
 {
+	GtkObjectClass *object_class = (GtkObjectClass *) class;
+	GtkWidgetClass *widget_class = (GtkWidgetClass *) class;
 	vObjectClass *vobject_class = (vObjectClass *) class;
 	ViewClass *view_class = (ViewClass *) class;
 
@@ -884,6 +1019,10 @@ columnview_class_init( ColumnviewClass *class )
 
 	/* Init methods.
 	 */
+	object_class->destroy = columnview_destroy;
+
+	widget_class->size_allocate = columnview_size_allocate;
+
 	vobject_class->refresh = columnview_refresh;
 
 	view_class->link = columnview_link;
@@ -897,6 +1036,8 @@ columnview_class_init( ColumnviewClass *class )
 		POPUP_FUNC( columnview_select_cb ) );
 	popup_add_but( pane, STOCK_DUPLICATE,
 		POPUP_FUNC( columnview_clone_cb ) );
+	popup_add_but( pane, _( "Merge Into Column" ),
+		POPUP_FUNC( columnview_merge_cb ) );
 	popup_add_but( pane, GTK_STOCK_SAVE_AS,
 		POPUP_FUNC( columnview_save_as_cb ) );
 	menu_add_sep( pane );
@@ -907,6 +1048,30 @@ columnview_class_init( ColumnviewClass *class )
 		POPUP_FUNC( columnview_destroy_cb ) );
 }
 
+static gboolean
+columnview_event_cb( GtkWidget *wid, GdkEvent *ev, Columnview *cview )
+{
+	gboolean handled;
+
+	handled = FALSE;
+
+        switch( ev->type ) {
+        case GDK_BUTTON_PRESS:
+                if( ev->button.button == 1 ) 
+			/* We want to sop our enclosing notebook seeing
+			 * left doubleclicks and creating new tabs. We want to
+			 * not block things like scroll events and
+			 * middle-drag.
+			 */
+                        handled = TRUE;
+
+	default:
+		break;
+	}
+
+	return( handled ); 
+}
+
 static void
 columnview_init( Columnview *cview )
 {
@@ -921,9 +1086,11 @@ columnview_init( Columnview *cview )
         cview->ly = -1;
 
 	cview->state = COL_WAIT;
-
 	cview->selected = FALSE;
 
+	cview->old_width = -1;
+	cview->old_height = -1;
+
         /* Make outer vb.
          */
         cview->main = gtk_event_box_new();
@@ -935,6 +1102,9 @@ columnview_init( Columnview *cview )
         /* Frame for whole title bar. Need an event_box to catch clicks.
          */
         cview->title = gtk_event_box_new();
+	gtk_widget_add_events( GTK_WIDGET( cview->title ), 
+		GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK |
+		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK ); 
         gtk_box_pack_start( GTK_BOX( cview->vbox ), 
 		cview->title, FALSE, FALSE, 0 );
         set_tooltip( cview->title, _( "Left-drag to move, left-double-click to "
@@ -944,7 +1114,7 @@ columnview_init( Columnview *cview )
         gtk_container_add( GTK_CONTAINER( cview->title ), frame );
         popup_attach( cview->title, columnview_menu, cview );
         gtk_signal_connect( GTK_OBJECT( cview->title ), "event",
-                GTK_SIGNAL_FUNC( columnview_event_cb ), cview );
+                GTK_SIGNAL_FUNC( columnview_title_event_cb ), cview );
 
         /* Layout contents of title bar.
          */
@@ -1003,6 +1173,12 @@ columnview_init( Columnview *cview )
 
         gtk_box_pack_start( GTK_BOX( cview ), cview->main, FALSE, FALSE, 0 );
 
+	/* We need to stop our enclosing thing seeing doubeclicks and all
+	 * that.
+	 */
+	gtk_signal_connect( GTK_OBJECT( cview ), "event", 
+		GTK_SIGNAL_FUNC( columnview_event_cb ), cview );
+
         gtk_widget_show_all( GTK_WIDGET( cview ) );
 }
 
