@@ -613,7 +613,11 @@ conversion_make_repaint( Conversion *conv, IMAGE *in )
 		(in->Type == IM_TYPE_LCH ||
 		in->Type == IM_TYPE_YXY ||
 		in->Type == IM_TYPE_UCS ||
+#if VIPS_VERSION_MAJOR > 7 || VIPS_VERSION_MINOR > 32
+		/* scRGB colourspace added in 7.32.
+		 */
 		in->Type == VIPS_INTERPRETATION_scRGB ||
+#endif
 		in->Type == IM_TYPE_LAB ||
 		in->Type == IM_TYPE_XYZ) ) {
 		IMAGE *t[2];
@@ -645,6 +649,7 @@ conversion_make_repaint( Conversion *conv, IMAGE *in )
 			in = t[1];
 		}
 
+#if VIPS_VERSION_MAJOR > 7 || VIPS_VERSION_MINOR > 32
 		if( in->Type == VIPS_INTERPRETATION_scRGB ) {
 			VipsImage *x;
 
@@ -656,6 +661,7 @@ conversion_make_repaint( Conversion *conv, IMAGE *in )
 
 			in = x;
 		}
+#endif
 
 		if( in->Type == IM_TYPE_YXY ) {
 			if( im_open_local_array( out, t, 2, "conv-1", "p" ) ||
