@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -850,16 +850,20 @@ imagepresent_left_press( Imagepresent *ip, GdkEvent *ev, int x, int y )
 
 	case IMAGEMODEL_PEN:
 	case IMAGEMODEL_SMUDGE:
-		imagemodel_refresh_nib( imagemodel );
 		imagepresent_snap_point( ip, x, y, &x, &y );
 		conversion_disp_to_im( conv, x, y, &ix, &iy );
 		ip->paint_last_x = ix;
 		ip->paint_last_y = iy;
 		handled = TRUE;
+
+		/* This can take ages and, via progress, actually process a
+		 * few events. Do it at the end.
+		 */
+		imagemodel_refresh_nib( imagemodel );
+
 		break;
 
 	case IMAGEMODEL_LINE:
-		imagemodel_refresh_nib( imagemodel );
 		imagepresent_snap_point( ip, x, y, &x, &y );
 		conversion_disp_to_im( conv, x, y, &ix, &iy );
 		ip->paint_last_x = ix;
@@ -869,6 +873,12 @@ imagepresent_left_press( Imagepresent *ip, GdkEvent *ev, int x, int y )
 			TRUE, REGIONVIEW_LINE, REGIONVIEW_RESIZE_BOTTOMRIGHT,
 			x, y );
 		handled = TRUE;
+
+		/* This can take ages and, via progress, actually process a
+		 * few events. Do it at the end.
+		 */
+		imagemodel_refresh_nib( imagemodel );
+
 		break;
 
 	case IMAGEMODEL_RECT:
@@ -1046,28 +1056,9 @@ imagepresent_left_release( Imagepresent *ip, GdkEvent *ev, int x, int y )
 			VipsBuf buf = VIPS_BUF_STATIC( txt );
 			Symbol *sym;
 
-			/* In compatibility mode, we need to un-offset, since
-			 * mark/etc. will re-offset.
-			 */
-			if( row->ws->compat_78 ) {
-				Conversion *conv = ip->id->conv;
-				IMAGE *im = imageinfo_get( FALSE, conv->ii );
-
-				ip->floating.left -= im->Xoffset;
-				ip->floating.top -= im->Yoffset;
-			}
-
 			switch( ip->regionview->type ) {
 			case REGIONVIEW_MARK:
-				/* How annoying, this used to be called
-				 * "Point".
-				 */
-				if( row->ws->compat_78 )
-					vips_buf_appends( &buf, "Point " );
-				else
-					vips_buf_appendf( &buf, "%s ", 
-						CLASS_MARK );
-
+				vips_buf_appendf( &buf, "%s ", CLASS_MARK );
 				row_qualified_name( row, &buf );
 				vips_buf_appendd( &buf, ip->floating.left );
 				vips_buf_appendd( &buf, ip->floating.top );
