@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -88,8 +88,17 @@ typedef struct _iObjectClass {
 	 * the caption to be an explanatory note about the object. 
 	 */
 	const char *(*generate_caption)( iObject * );
+
+	/* The i18n name for this class we show the user. FOr example,
+	 * Workspace is referred to as "tab" by the user.
+	 */
+	const char *user_name;
 } iObjectClass;
 
+#define IOBJECT_GET_CLASS_NAME( obj ) \
+	((G_TYPE_INSTANCE_GET_CLASS( (obj), \
+		TYPE_IOBJECT, iObjectClass ))->user_name)
+
 void *iobject_destroy( iObject *iobject );
 void *iobject_changed( iObject *iobject );
 void *iobject_info( iObject *iobject, VipsBuf * );
