@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -33,13 +33,6 @@
 
 #include "ip.h"
 
-/* We have gtksheet patched into the nip sources as a temp measure, so call 
- * directly.
- */
-#ifdef USE_GTKSHEET
-#include "gtksheet.h"
-#endif /*USE_GTKSHEET*/
-
 /* Round N down to P boundary.
  */
 #define ROUND_DOWN(N,P) ((N) - ((N) % P))
@@ -58,7 +51,7 @@ static const int matrixview_max_height = 10;
  */
 static const int matrixview_column_width = 70;
 
-/* Limit non-gtksheet display size with these ... could be prefs?
+/* Limit number of sub-widgets with this ... could be prefs?
  */
 static const int matrixview_max_cells = 100;
 
@@ -81,32 +74,10 @@ matrixview_destroy( GtkObject *object )
     	/* My instance destroy stuff.
     	 */
     	IM_FREEF( g_slist_free, matrixview->items );
-	IM_FREE( matrixview->cell_text );
 
     	GTK_OBJECT_CLASS( parent_class )->destroy( object );
 }
 
-#ifdef USE_GTKSHEET
-static gboolean
-matrixview_scan_string( char *txt, double *out, gboolean *changed )
-{
-    	double v;
-
-    	if( sscanf( txt, "%lg", &v ) != 1 ) {
-		error_top( _( "Bad floating point number." ) );
-		error_sub( _( "\"%s\" is not a floating point number." ), txt );
-    		return( FALSE );
-    	}
-
-    	if( *out != v ) {
-    		*out = v;
-    		*changed = TRUE;
-    	}
-
-    	return( TRUE );
-}
-#endif /*USE_GTKSHEET*/
-
 static gboolean
 matrixview_scan_text( Matrixview *matrixview, GtkWidget *txt, 
     	double *out, gboolean *changed )
@@ -132,6 +103,8 @@ matrixview_scan( View *view )
 {
     	Matrixview *matrixview = MATRIXVIEW( view );
     	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
+	int width = matrix->value.width;
+	int height = matrix->value.height;
     	Expr *expr = HEAPMODEL( matrix )->row->expr;
 
     	gboolean changed;
@@ -167,22 +140,15 @@ matrixview_scan( View *view )
     		return( view );
     	}
 
-    	/* Loop thru' all matrix widgets.
+    	/* Loop thru' all matrix widgets. tsliders have text fields we must
+	 * scan too.
     	 */
     	if( matrixview->items ) 
-    		for( p = matrixview->items, y = 0; y < matrixview->height; y++ )
-    			for( x = 0; x < matrixview->width; x++, p = p->next ) {
+    		for( p = matrixview->items, y = 0; y < height; y++ )
+    			for( x = 0; x < width; x++, p = p->next ) {
     				GtkWidget *item = GTK_WIDGET( p->data );
-				int i = x + y * matrix->value.width;
-
-    				GtkWidget *entry;
-
-    				/* It's either an entry, or a tslider.
-    				 */
-    				if( IS_TSLIDER( item ) ) 
-    					entry = TSLIDER( item )->entry;
-    				else
-    					entry = item;
+    				GtkWidget *entry = TSLIDER( item )->entry;
+				int i = x + y * width;
 
     				if( !matrixview_scan_text( matrixview, entry,
     					&matrix->value.coeff[i], &changed ) ) {
@@ -195,28 +161,31 @@ matrixview_scan( View *view )
     				}
     			}
 
-#ifdef USE_GTKSHEET
-    	if( matrixview->sheet ) {
-    		GtkSheet *sheet = GTK_SHEET( matrixview->sheet );
+	if( matrixview->store ) {
+		GtkTreeModel *tree = GTK_TREE_MODEL( matrixview->store );
 
-    		for( y = 0; y < matrixview->height; y++ )
-    			for( x = 0; x < matrixview->width; x++ ) {
-    				char *txt = gtk_sheet_cell_get_text(
-    					sheet, y, x );
-				int i = x + y * matrix->value.width;
+		GtkTreeIter iter;
 
-    				if( !matrixview_scan_string( txt,
-    					&matrix->value.coeff[i], &changed ) ) {
-					error_top( _( "Bad value." ) );
-					error_sub( _( "Cell (%d, %d):\n%s" ), 
-    						x, y, error_get_sub() );
-					expr_error_set( expr );
+		gtk_tree_model_get_iter_first( tree, &iter );
 
-    					return( view );
-    				}
-    			}
-    	}
-#endif /*USE_GTKSHEET*/
+		for( y = 0; y < height; y++ ) {
+			for( x = 0; x < width; x++ ) {
+				double *out = 
+					&matrix->value.coeff[x + y * width];
+
+				double d;
+
+				gtk_tree_model_get( tree, &iter, x, &d, -1 );
+
+				if( *out != d ) {
+					*out = d;
+					changed = TRUE;
+				}
+			}
+
+			gtk_tree_model_iter_next( tree, &iter );
+		}
+	}
 
     	if( changed ) 
     		classmodel_update( CLASSMODEL( matrix ) ) ;
@@ -380,16 +349,20 @@ matrixview_slider_build( Matrixview *matrixview )
     		}
 }
 
-static void
-matrixview_text_focus_in( GtkWidget *entry )
+static gboolean
+matrixview_text_focus_in( GtkWidget *entry, GdkEvent *event, void *data )
 {
     	gtk_editable_select_region( GTK_EDITABLE( entry ), 0, -1 );
+
+	return( FALSE );
 }
 
-static void
-matrixview_text_focus_out( GtkWidget *entry )
+static gboolean
+matrixview_text_focus_out( GtkWidget *entry, GdkEvent *event, void *data )
 {
     	gtk_editable_select_region( GTK_EDITABLE( entry ), 0, 0 );
+
+	return( FALSE );
 }
 
 static void
@@ -434,7 +407,6 @@ matrixview_text_build_scale_offset( Matrixview *matrixview )
 	UNREF( group );
 }
 
-#ifndef USE_GTKSHEET
 /* Make a GtkListStore from a MatrixValue.
  */
 GtkListStore *
@@ -466,6 +438,41 @@ matrixview_liststore_new( MatrixValue *matrixvalue )
 	return( store );
 }
 
+static void
+matrixview_edited_cb( GtkCellRendererText *renderer, 
+	char *path, char *new_text, void *user_data )
+{
+	Matrixview *matrixview = MATRIXVIEW( user_data );
+	GtkTreeModel *tree = GTK_TREE_MODEL( matrixview->store );
+	GtkTreeIter iter;
+
+	if( gtk_tree_model_get_iter_from_string( tree, &iter, path ) ) {
+		int col = GPOINTER_TO_INT( g_object_get_data( 
+			G_OBJECT( renderer ), "nip2_column_num" ) );
+
+		gtk_list_store_set( GTK_LIST_STORE( tree ), &iter, 
+			col, atof( new_text ),
+			-1 ); 
+
+		view_scannable_register( VIEW( matrixview ) );
+		symbol_recalculate_all();
+	}
+}
+
+static void
+matrixview_cell_data_cb( GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
+	GtkTreeModel *tree, GtkTreeIter *iter, void *data )
+{
+	int col = GPOINTER_TO_INT( g_object_get_data( 
+		G_OBJECT( cell ), "nip2_column_num" ) );
+	double d;
+	char buf[256];
+
+	gtk_tree_model_get( tree, iter, col, &d, -1 );
+	vips_snprintf( buf, 256, "%g", d ); 
+	g_object_set( cell, "text", buf, NULL );
+}
+
 /* Build a set of text items for a matrix. 
  */
 static void
@@ -473,24 +480,31 @@ matrixview_text_build( Matrixview *matrixview )
 {
     	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
 
-	GtkCellRenderer *renderer;
 	int i;
 	GtkTreeViewColumn *column;
     	int cell_height;
 	GtkTreeSelection *selection;
 
+	if( !matrix->value.coeff )
+		return;
+
 	matrixview->store = matrixview_liststore_new( &matrix->value );
 	matrixview->sheet = gtk_tree_view_new_with_model( 
 		GTK_TREE_MODEL( matrixview->store ) );
 	gtk_tree_view_set_headers_visible( GTK_TREE_VIEW( matrixview->sheet ),
 		FALSE );
 
-	renderer = gtk_cell_renderer_text_new();
-	g_object_set( renderer, "editable", TRUE, NULL );
-
 	for( i = 0; i < matrix->value.width; i++ ) {
+		GtkCellRenderer *renderer;
 		char buf[256];
 
+		renderer = gtk_cell_renderer_text_new();
+		g_object_set( renderer, "editable", TRUE, NULL );
+		g_object_set_data( G_OBJECT( renderer ), 
+			"nip2_column_num", GINT_TO_POINTER( i ) );
+		g_signal_connect( G_OBJECT( renderer ), "edited",
+			G_CALLBACK( matrixview_edited_cb ), matrixview );
+
 		column = gtk_tree_view_column_new();
 		gtk_tree_view_column_set_sizing( column, 
 			GTK_TREE_VIEW_COLUMN_FIXED );
@@ -502,6 +516,8 @@ matrixview_text_build( Matrixview *matrixview )
 		gtk_tree_view_column_set_attributes( column, renderer, 
 			"text", i, 
 			NULL );
+		gtk_tree_view_column_set_cell_data_func( column, renderer, 
+			matrixview_cell_data_cb, NULL, NULL ); 
 		gtk_tree_view_append_column( GTK_TREE_VIEW( matrixview->sheet ),
 			column );
 	}
@@ -556,14 +572,6 @@ matrixview_text_build( Matrixview *matrixview )
 		width = IM_MIN( matrix->value.width, matrixview_max_width );
 		height = IM_MIN( matrix->value.height, matrixview_max_height );
 
-		/* If we're showing row/column headers, need an extra
-		 * row/column.
-		if( matrixview->width > matrixview_max_width )
-			height += 1;
-		if( matrixview->height > matrixview_max_height )
-			width += 1;
-		 */
-
 		/* Convert to pixels.
 		 */
 		width *= matrixview_column_width;
@@ -592,253 +600,6 @@ matrixview_text_build( Matrixview *matrixview )
     		 */
     		matrixview_text_build_scale_offset( matrixview );
 }
-#endif /*!USE_GTKSHEET*/
-
-#ifdef USE_GTKSHEET
-static int 
-matrixview_text_traverse( GtkSheet *sheet,
-    	int old_row, int old_col, int *new_row, int *new_col,
-    	Matrixview *matrixview )
-{
-    	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
-    	Row *row = HEAPMODEL( matrix )->row;
-
-    	char *new_text = gtk_sheet_cell_get_text( sheet, *new_row, *new_col );
-
-    	char txt[MAX_LINELENGTH];
-    	VipsBuf buf = VIPS_BUF_STATIC( txt );
-
-	/* Make a note of what's in this cell before any editing ... "changed"
-	 * does a strcmp() on this to spot edit actions.
-	 */
-	IM_SETSTR( matrixview->cell_text, new_text );
-	matrixview->cell_row = *new_row;
-	matrixview->cell_col = *new_col;
-
-    	row_qualified_name( row, &buf );
-	/* Expands to (eg) "A2: cell (1,2): 45" ... status line display during
-	 * matrix traverse.
-	 */
-    	vips_buf_appendf( &buf, _( ": cell (%d, %d): %s" ), 
-		*new_col, *new_row, new_text );
-	workspace_set_status( row->ws, "%s", vips_buf_all( &buf ) );
-
-    	return( TRUE );
-}
-
-static void 
-matrixview_text_changed( GtkSheet *sheet,
-    	int row, int col, Matrixview *matrixview )
-{
-	/* "changed" is emitted on many changes :-( compare text with start
-	 * text to see if we have an edit.
-	 */
-	if( matrixview->cell_text && 
-		!VIEW( matrixview )->scannable &&
-		row == matrixview->cell_row && col == matrixview->cell_col ) {
-		char *text = gtk_sheet_cell_get_text( sheet, row, col );
-
-		if( strcmp( matrixview->cell_text, text ) != 0 ) {
-#ifdef DEBUG
-			printf( "matrixview_text_changed: "
-				"old = \"%s\", new = \"%s\"\n",
-				matrixview->cell_text, text );
-#endif /*DEBUG*/
-
-			view_changed_cb( VIEW( matrixview ) );
-		}
-	}
-}
-
-static void 
-matrixview_select_range( GtkSheet *sheet, 
-	GtkSheetRange *range, Matrixview *matrixview )
-{
-    	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
-
-	matrix_select( matrix,
-		range->col0, range->row0, 
-		(range->coli - range->col0) + 1, 
-		(range->rowi - range->row0) + 1 );
-}
-
-static void 
-matrixview_unselect_range( GtkSheet *sheet, 
-	GtkSheetRange *range, Matrixview *matrixview )
-{
-    	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
-
-	matrix_deselect( matrix );
-}
-
-static gboolean
-matrixview_text_event( GtkWidget *widget, 
-	GdkEvent *ev, Matrixview *matrixview )
-{
-        if( ev->type != GDK_KEY_PRESS || ev->key.keyval != GDK_Return )
-                return( FALSE );
-
-	view_activate_cb( VIEW( matrixview ) );
-
-        return( FALSE );
-}
-
-static void
-matrixview_text_sheet_build( Matrixview *matrixview )
-{
-	GtkWidget *entry;
-	GtkAdjustment *hadj, *vadj;
-
-    	int cell_width;
-    	int cell_height;
-
-    	matrixview->sheet = gtk_sheet_new( matrixview->height, 
-		matrixview->width, "" );
-
-	/* Cool, but causes too many resizing problems in an embedded widget.
-	 */
-	gtk_sheet_columns_set_resizable( GTK_SHEET( matrixview->sheet ), 
-		FALSE );
-	gtk_sheet_rows_set_resizable( GTK_SHEET( matrixview->sheet ), 
-		FALSE );
-
-    	cell_width = GTK_SHEET( matrixview->sheet )->row_title_area.width;
-    	cell_height = GTK_SHEET( matrixview->sheet )->column_title_area.height;
-
-    	gtk_signal_connect( GTK_OBJECT( matrixview->sheet ), "traverse",
-    		GTK_SIGNAL_FUNC( matrixview_text_traverse ), matrixview );
-    	gtk_signal_connect( GTK_OBJECT( matrixview->sheet ), "changed",
-    		GTK_SIGNAL_FUNC( matrixview_text_changed ), matrixview );
-
-    	gtk_sheet_set_selection_mode( GTK_SHEET( matrixview->sheet ), 
-		GTK_SELECTION_MULTIPLE );
-
-    	g_signal_connect( matrixview->sheet, "select-range",
-    		G_CALLBACK( matrixview_select_range ), matrixview );
-    	g_signal_connect( matrixview->sheet, "unselect-range",
-    		G_CALLBACK( matrixview_unselect_range ), matrixview );
-
-	/* We can't connect to "activate" on sheet's entry :-( most
-	 * gtk_sheets fail to emit it. Have to parse events ourselves.
-	 */
-	entry = gtk_sheet_get_entry( GTK_SHEET( matrixview->sheet ) );
-	gtk_signal_connect( GTK_OBJECT( entry ), "event",
-    		GTK_SIGNAL_FUNC( matrixview_text_event ), 
-		GTK_OBJECT( matrixview ) );
-
-	/* For large matricies, display in a scrolled window.
-	 */
-	if( matrixview->width > matrixview_max_width || 
-		matrixview->height > matrixview_max_height ) {
-		GtkRequisition requisition;
-		gint spacing;
-		int border;
-		int width, height;
-
-		matrixview->swin = gtk_scrolled_window_new( NULL, NULL );
-		gtk_box_pack_start( GTK_BOX( matrixview->box ), 
-			matrixview->swin, FALSE, FALSE, 0 );
-		gtk_container_add( GTK_CONTAINER( matrixview->swin ), 
-			matrixview->sheet );
-		hadj = gtk_scrolled_window_get_hadjustment( 
-			GTK_SCROLLED_WINDOW( matrixview->swin ) );
-		vadj = gtk_scrolled_window_get_vadjustment( 
-			GTK_SCROLLED_WINDOW( matrixview->swin ) );
-
-		/* Pick a size for the scrolled window. This is horrible! We
-		 * need the inner area of the swin to be a certain size, so we
-		 * need to allow extra space for the sccrollbars and the swin
-		 * padding.
-		 */
-
-		/* There is a thing in swin in 2.8+ to get the scrollbar out, 
-		 * but we want to work with earlier gtk as well. Yuk!
-		 */
-		gtk_widget_size_request( 
-			GTK_SCROLLED_WINDOW( matrixview->swin )->hscrollbar, 
-			&requisition);
-		gtk_widget_style_get( GTK_WIDGET( matrixview->swin ),
-			"scrollbar-spacing", &spacing,
-			NULL );
-		border = requisition.height + spacing;
-
-		/* Subarea of matrix we show, in cells.
-		 */
-		width = IM_MIN( matrixview->width, matrixview_max_width );
-		height = IM_MIN( matrixview->height, matrixview_max_height );
-
-		/* If we're showing row/column headers, need an extra
-		 * row/column.
-		 */
-		if( matrixview->width > matrixview_max_width )
-			height += 1;
-		if( matrixview->height > matrixview_max_height )
-			width += 1;
-
-		/* Convert to pixels.
-		 */
-		width *= cell_width;
-		height *= cell_height;
-
-		/* Will we be showing scrollbars? Need to add a bit.
-		 */
-		if( matrixview->width > matrixview_max_width )
-			height += border;
-		if( matrixview->height > matrixview_max_height )
-			width += border;
-
-		gtk_widget_set_size_request( GTK_WIDGET( matrixview->swin ), 
-			width, height );
-
-		/* If we're not showing scrollbars, we can hide the
-		 * row/column headers.
-		 */
-		if( matrixview->height <= matrixview_max_height )
-			gtk_sheet_hide_row_titles( 
-				GTK_SHEET( matrixview->sheet ) );
-		if( matrixview->width <= matrixview_max_width )
-			gtk_sheet_hide_column_titles( 
-				GTK_SHEET( matrixview->sheet ) );
-
-		gtk_scrolled_window_set_policy( 
-			GTK_SCROLLED_WINDOW( matrixview->swin ),
-			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-	}	
-	else {
-		hadj = GTK_ADJUSTMENT( 
-			gtk_adjustment_new( 0, 0, 100, 10, 10, 10 ) );
-		vadj = GTK_ADJUSTMENT( 
-			gtk_adjustment_new( 0, 0, 100, 10, 10, 10 ) );
-
-		/* No need for col/row titles for small matricies.
-		 */
-		gtk_sheet_hide_column_titles( GTK_SHEET( matrixview->sheet ) );
-		gtk_sheet_hide_row_titles( GTK_SHEET( matrixview->sheet ) );
-
-		gtk_widget_set_size_request( GTK_WIDGET( matrixview->sheet ), 
-			matrixview->width * cell_width, 
-			matrixview->height * cell_height );
-
-		gtk_box_pack_start( GTK_BOX( matrixview->box ), 
-			matrixview->sheet, FALSE, FALSE, 0 );
-	}
-
-    	gtk_sheet_set_hadjustment( GTK_SHEET( matrixview->sheet ), hadj );
-    	gtk_sheet_set_vadjustment( GTK_SHEET( matrixview->sheet ), vadj );
-}
-
-static void
-matrixview_text_build( Matrixview *matrixview )
-{
-	/* Sheet hates zero width/height. Can happen during class construct.
-	 */
-	if( matrixview->width > 0 && matrixview->height > 0 )
-		matrixview_text_sheet_build( matrixview );
-
-    	if( matrixview->display == MATRIX_DISPLAY_TEXT_SCALE_OFFSET )
-    		matrixview_text_build_scale_offset( matrixview );
-}
-#endif /*USE_GTKSHEET*/
 
 /* Set the label on a toggle button to reflect its value.
  */
@@ -918,84 +679,37 @@ matrixview_text_set( Matrixview *matrixview, GtkWidget *txt, double val )
     	}
 }
 
-#ifndef USE_GTKSHEET
 /* Fill the widgets!
  */
 static void
 matrixview_text_refresh( Matrixview *matrixview )
 {
     	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
+	MatrixValue *matrixvalue = &matrix->value;
+	int width = matrixvalue->width;
+	int height = matrixvalue->height;
+	GtkTreeModel *tree = GTK_TREE_MODEL( matrixview->store );
 
-    	matrixview_text_set( matrixview, matrixview->scale, matrix->scale );
-    	matrixview_text_set( matrixview, matrixview->offset, matrix->offset );
-}
-#endif /*!USE_GTKSHEET*/
+	int x, y;
+	GtkTreeIter iter;
 
-#ifdef USE_GTKSHEET
-static void
-matrixview_text_refresh( Matrixview *matrixview )
-{
-    	Matrix *matrix = MATRIX( VOBJECT( matrixview )->iobject );
-	GtkSheetRange *range = &GTK_SHEET( matrixview->sheet )->range;
-
-    	int x, y;
-
-	/* width and height can be zero (during class construct), in which
-	 * case they'll be no gtk_sheet.
-	 */
-	if( !matrixview->sheet )
+	if( !matrixvalue->coeff )
 		return;
 
-	gtk_sheet_freeze( GTK_SHEET( matrixview->sheet ) );
-
-    	for( y = 0; y < matrixview->height; y++ )
-    		for( x = 0; x < matrixview->width; x++ ) {
-    			int i = x + y * matrix->value.width;
-    			double coeff = matrix->value.coeff[i];
-    			char buf[256];
-
-    			snprintf( buf, 256, "%g", coeff );
-			gtk_signal_handler_block_by_data( 
-				GTK_OBJECT( matrixview->sheet ), matrixview );
-    			gtk_sheet_set_cell_text( GTK_SHEET( matrixview->sheet ),
-                                        y, x, buf );
-			gtk_signal_handler_unblock_by_data( 
-				GTK_OBJECT( matrixview->sheet ), matrixview );
-
-			if( x == matrixview->cell_col && 
-				y == matrixview->cell_row ) 
-				IM_SETSTR( matrixview->cell_text, buf );
-    		}
-
-	/* Is the model's selection different from ours? Update ours if it is.
-	 * Annoyingly, we can only change the selection when the widget's
-	 * realized.
-	 */
-	if( GTK_WIDGET_REALIZED( matrixview->sheet ) ) {
-		if( !matrix->selected )
-			gtk_sheet_unselect_range( 
-				GTK_SHEET( matrixview->sheet ) );
-		else if( range->col0 != matrix->range.left ||
-			range->coli != IM_RECT_RIGHT( &matrix->range ) - 1 ||
-			range->row0 != matrix->range.top ||
-			range->rowi != IM_RECT_BOTTOM( &matrix->range ) - 1 ) {
-			GtkSheetRange new_range;
-
-			new_range.col0 = matrix->range.left;
-			new_range.row0 = matrix->range.top;
-			new_range.coli = IM_RECT_RIGHT( &matrix->range );
-			new_range.rowi = IM_RECT_BOTTOM( &matrix->range );
-			gtk_sheet_select_range( GTK_SHEET( matrixview->sheet ),
-				&new_range );
-		}
-	}
-
-	gtk_sheet_thaw( GTK_SHEET( matrixview->sheet ) );
-
     	matrixview_text_set( matrixview, matrixview->scale, matrix->scale );
     	matrixview_text_set( matrixview, matrixview->offset, matrix->offset );
+
+	gtk_tree_model_get_iter_first( tree, &iter );
+
+	for( y = 0; y < height; y++ ) {
+		for( x = 0; x < width; x++ ) 
+			gtk_list_store_set( matrixview->store, &iter, 
+				x, matrixvalue->coeff[x + y * width], 
+				-1 );
+
+		gtk_tree_model_iter_next( tree, &iter );
+	}
 }
-#endif /*USE_GTKSHEET*/
 
 static void
 matrixview_refresh( vObject *vobject )
@@ -1072,9 +786,6 @@ matrixview_refresh( vObject *vobject )
     		IM_FREEF( gtk_widget_destroy, matrixview->swin );
     		IM_FREEF( g_slist_free, matrixview->items );
     		IM_FREEF( gtk_widget_destroy, matrixview->cbox );
-		IM_FREE( matrixview->cell_text );
-		matrixview->cell_row = -1;
-		matrixview->cell_col = -1;
     		matrixview->scale = NULL;
     		matrixview->offset = NULL;
 
@@ -1206,9 +917,6 @@ matrixview_init( Matrixview *matrixview )
     	matrixview->store = NULL;
     	matrixview->sheet = NULL;
     	matrixview->swin = NULL;
-    	matrixview->cell_text = NULL;
-    	matrixview->cell_row = -1;
-    	matrixview->cell_col = -1;
     	matrixview->table = NULL;
     	matrixview->items = NULL;
     	matrixview->width = -1;
