@@ -337,7 +337,21 @@ static ClassmodelMember plot_options[] = {
 		G_STRUCT_OFFSET( Plot, ymin ) },
 	{ CLASSMODEL_MEMBER_DOUBLE, NULL, 0,
 		"ymax", "ymax", N_( "Ymax" ),
-		G_STRUCT_OFFSET( Plot, ymax ) }
+		G_STRUCT_OFFSET( Plot, ymax ) },
+	{ CLASSMODEL_MEMBER_STRING, NULL, 0,
+		MEMBER_CAPTION, "caption", N_( "Caption" ),
+		G_STRUCT_OFFSET( Plot, caption ) },
+	{ CLASSMODEL_MEMBER_STRING, NULL, 0,
+		MEMBER_XCAPTION, "xcaption", N_( "X Axis Caption" ),
+		G_STRUCT_OFFSET( Plot, xcaption ) },
+	{ CLASSMODEL_MEMBER_STRING, NULL, 0,
+		MEMBER_YCAPTION, "ycaption", N_( "Y Axis Caption" ),
+		G_STRUCT_OFFSET( Plot, ycaption ) },
+	{ CLASSMODEL_MEMBER_STRING_LIST, NULL, 0,
+		MEMBER_SERIES_CAPTIONS, "series_captions", 
+			N_( "Series Captions" ),
+		G_STRUCT_OFFSET( Plot, series_captions ) }
+
 };
 
 static ClassmodelMember plot_members[] = {
@@ -424,6 +438,10 @@ plot_reset( Classmodel *classmodel )
 	plot->xmax = PLOT_RANGE_UNSET;
 	plot->ymin = PLOT_RANGE_UNSET;
 	plot->ymax = PLOT_RANGE_UNSET;
+	IM_SETSTR( plot->caption, NULL ); 
+	IM_SETSTR( plot->xcaption, NULL ); 
+	IM_SETSTR( plot->ycaption, NULL ); 
+	IM_FREEF( slist_free_all, plot->series_captions );
 }
 
 static gboolean
@@ -615,6 +633,7 @@ plot_new_gplot( Plot *plot )
 		GogSeries *series;
 		GOData *data;
 		GError *error;
+		char *caption;
 
                 series = gog_plot_new_series( gplot );
 		data = go_data_vector_val_new( plot->xcolumn[i], plot->rows, 
@@ -624,6 +643,14 @@ plot_new_gplot( Plot *plot )
 			NULL );
 		gog_series_set_dim( series, 1, data, &error );
 
+		if( (caption = (char *) 
+			g_slist_nth_data( plot->series_captions, i )) ) 
+			caption = g_strdup( caption );
+		else 
+			caption = g_strdup_printf( "Band %d", i ); 
+		data = go_data_scalar_str_new( caption, TRUE );
+		gog_series_set_name( series, (GODataScalar *) data, &error );
+
 		if( i < IM_NUMBER( default_colour ) ) {
 			GOStyle *style;
 
@@ -650,4 +677,168 @@ plot_new_gplot( Plot *plot )
 	return( gplot );
 }
 
+static void
+plot_grid_add( GogAxis *axis )
+{
+	GogGridLine *ggl;
+
+	if( !gog_object_get_child_by_name( GOG_OBJECT( axis ), "MajorGrid" ) ) {
+		ggl = g_object_new( GOG_TYPE_GRID_LINE, 
+			"is-minor", FALSE, NULL );
+		gog_object_add_by_name( GOG_OBJECT( axis ), 
+			"MajorGrid", GOG_OBJECT( ggl ) );
+	}
+
+	if( !gog_object_get_child_by_name( GOG_OBJECT( axis ), "MinorGrid" ) ) {
+		ggl = g_object_new( GOG_TYPE_GRID_LINE, 
+			"is-minor", TRUE, NULL );
+		gog_object_add_by_name( GOG_OBJECT( axis ), 
+			"MinorGrid", GOG_OBJECT( ggl ) );
+	}
+
+	g_object_set( axis, "pos", GOG_AXIS_CROSS, NULL );
+}
+
+static void
+plot_set_title( GogObject *thing, const char *role, const char *text )
+{
+	GogObject *title;
+
+	title = gog_object_get_child_by_name( thing, role );
+	if( text && !title ) {
+		title = g_object_new( GOG_TYPE_LABEL, NULL );
+		gog_object_add_by_name( thing, role, title );
+	}
+	else if( !text && title ) {
+		gog_object_clear_parent( title );
+		UNREF( title ); 
+	}
+
+	if( text && title ) {
+		GOData *data;
+
+		data = go_data_scalar_str_new( text, FALSE );
+		gog_dataset_set_dim( GOG_DATASET( title ), 0, data, NULL );
+	}
+}
+
+void
+plot_style_main( Plot *plot, GogChart *gchart )
+{
+	GSList *axes;
+	GogAxis *axis;
+	GogObject *legend;
+
+	axes = gog_chart_get_axes( gchart, GOG_AXIS_X );
+	axis = GOG_AXIS( axes->data );
+	g_slist_free( axes );
+
+	gog_axis_set_bounds( axis, plot->xmin, plot->xmax );
+	plot_set_title( GOG_OBJECT( axis ), "Label", plot->xcaption ); 
+	plot_grid_add( axis ); 
+
+	axes = gog_chart_get_axes( gchart, GOG_AXIS_Y );
+	axis = GOG_AXIS( axes->data );
+	g_slist_free( axes );
+
+	gog_axis_set_bounds( axis, plot->ymin, plot->ymax );
+	plot_set_title( GOG_OBJECT( axis ), "Label", plot->ycaption ); 
+	plot_grid_add( axis ); 
+
+	legend = gog_object_get_child_by_name( GOG_OBJECT( gchart ), "Legend" );
+	if( plot->columns > 1 &&
+		!legend ) {
+		legend = g_object_new( GOG_TYPE_LEGEND, NULL );
+		gog_object_add_by_name( GOG_OBJECT( gchart ), 
+			"Legend", GOG_OBJECT( legend ) );
+	}
+	else if( plot->columns == 1 &&
+		legend ) {
+		gog_object_clear_parent( legend );
+		UNREF( legend ); 
+	}
+
+	plot_set_title( GOG_OBJECT( gchart ), "Title", plot->caption ); 
+}
+
+void
+plot_style_thumbnail( Plot *plot, GogChart *gchart )
+{
+	GSList *axes;
+	GogAxis *axis;
+
+	axes = gog_chart_get_axes( gchart, GOG_AXIS_X );
+	axis = GOG_AXIS( axes->data );
+	g_slist_free( axes );
+
+	g_object_set( axis, 
+		"major-tick-labeled", FALSE, 
+		"major-tick-size-pts", 0,
+		"pos", GOG_AXIS_CROSS,
+		NULL );
+	gog_axis_set_bounds( axis, plot->xmin, plot->xmax );
+
+	axes = gog_chart_get_axes( gchart, GOG_AXIS_Y );
+	axis = GOG_AXIS( axes->data );
+	g_slist_free( axes );
+
+	g_object_set( axis, 
+		"major-tick-labeled", FALSE, 
+		"major-tick-size-pts", 0,
+		"pos", GOG_AXIS_CROSS,
+		NULL );
+	gog_axis_set_bounds( axis, plot->ymin, plot->ymax );
+}
+
+Imageinfo *
+plot_to_image( Plot *plot, Reduce *rc, double dpi )
+{
+	GogGraph *ggraph;
+	GogChart *gchart;
+	GogPlot *gplot;
+	GogRenderer *renderer;
+	GdkPixbuf *pixbuf;
+	double width_in_pts, height_in_pts;
+	Imageinfo *ii;
+
+	ggraph = g_object_new( GOG_TYPE_GRAPH, NULL );
+
+	gchart = g_object_new( GOG_TYPE_CHART, NULL );
+	gog_object_add_by_name( GOG_OBJECT( ggraph ), 
+		"Chart", GOG_OBJECT( gchart ) );
+
+	gplot = plot_new_gplot( plot );
+	gog_object_add_by_name( GOG_OBJECT( gchart ), 
+		"Plot", GOG_OBJECT( gplot ) );
+
+	plot_style_main( plot, gchart ); 
+
+	renderer = gog_renderer_new( ggraph );
+
+	gog_graph_force_update( ggraph );
+
+	gog_graph_get_size( ggraph, &width_in_pts, &height_in_pts);
+
+	gog_renderer_update( renderer, 
+		width_in_pts * dpi / 72.0, height_in_pts * dpi / 72.0 );
+
+	pixbuf = gog_renderer_get_pixbuf( renderer );
+
+	if( !(ii = imageinfo_new_from_pixbuf( main_imageinfogroup, rc->heap, 
+		pixbuf )) ) { 
+		UNREF( renderer );
+		UNREF( ggraph );
+
+		return( NULL ); 
+	}
+
+	/* Don't unref the pixbuf, we don't own it.
+	 */
+
+	UNREF( renderer );
+	UNREF( ggraph );
+
+	return( ii ); 
+}
+
 #endif /*HAVE_LIBGOFFICE*/
